@@ -8,7 +8,6 @@ use IO::Async::Channel;
 use IO::Async::Loop;
 use Future::AsyncAwait;
 use MIDI::RtMidi::FFI::Device;
-use Time::HiRes qw/ gettimeofday tv_interval /;
 
 my $loop = IO::Async::Loop->new;
 my $midi_ch = IO::Async::Channel->new;
@@ -17,12 +16,11 @@ my $midi_rtn = IO::Async::Routine->new(
     channels_out => [ $midi_ch ],
     code => sub {
         my $midi_in = MIDI::RtMidi::FFI::Device->new( type => 'in' );
-        $midi_in->open_port_by_name( qr/LKMK3/i ); # LaunchKey Mk 3
+        $midi_in->open_port_by_name( qr/LKMK3|oxy/i );
 
-        $midi_in->set_callback(
-            sub( $ts, $msg, $data = undef ) {
-                my $t0 = [ gettimeofday ];
-                $midi_ch->send( [ $t0, $ts, $msg ] );
+        $midi_in->set_callback_decoded(
+            sub( $ts, $msg, $event ) {
+                $midi_ch->send( $event );
             }
         );
 
@@ -35,9 +33,7 @@ $SIG{TERM} = sub { $midi_rtn->kill('TERM') };
 
 async sub process_midi_events {
     while ( my $event = await $midi_ch->recv ) {
-        say "recv took " . tv_interval( $event->[0] ) . "s";
-        say "ts " . $event->[1] . "s";
-        say unpack 'H*', $event->[2];
+        say join " ", $event->@*;
     }
 }
 
